@@ -333,8 +333,8 @@ let ClipboardDialog = class ClipboardDialog extends St.Widget {
 		});
 
 		// Connect activation
-		item.connect('activate', async () => {
-			await this.ext.clipboardManager?.pasteEntry(entry);
+		item.connect('activate', () => {
+			this.emit('paste', entry);
 			this.close();
 		});
 		item.connect('activate-default', () => {
@@ -546,6 +546,11 @@ ClipboardDialog = __decorate(
 			Properties: {
 				opened: GObject.ParamSpec.boolean('opened', null, null, GObject.ParamFlags.READABLE, false),
 			},
+			Signals: {
+				paste: {
+					param_types: [GObject.TYPE_JSOBJECT],
+				},
+			},
 		}),
 	],
 	ClipboardDialog,
