@@ -271,7 +271,7 @@ let SearchEntry = class SearchEntry extends St.Entry {
 
 	constructor(ext) {
 		super({
-			style_class: 'search-entry',
+			style_class: 'clipboard-search-entry',
 			hint_text: _('Type to search'),
 			can_focus: true,
 			x_align: Clutter.ActorAlign.CENTER,
